@@ -12,11 +12,10 @@ import (
 	"strings"
 	"testing"
 
-	git2 "github.com/fluxcd/go-git/v5"
-	"github.com/fluxcd/go-git/v5/plumbing"
+	git2 "github.com/go-git/go-git/v5"
+	"github.com/go-git/go-git/v5/plumbing"
 	"github.com/kluctl/kluctl/v2/pkg/git"
 	"github.com/kluctl/kluctl/v2/pkg/git/auth"
-	git_url "github.com/kluctl/kluctl/v2/pkg/git/git-url"
 	ssh_pool "github.com/kluctl/kluctl/v2/pkg/git/ssh-pool"
 	"github.com/kluctl/kluctl/v2/pkg/k8s"
 	"github.com/kluctl/kluctl/v2/pkg/repocache"
@@ -223,7 +222,7 @@ func TestVarsLoader_Git(t *testing.T) {
 	}, "")
 
 	testVarsLoader(t, func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
-		url, _ := git_url.Parse(gs.GitRepoUrl("repo"))
+		url, _ := types.ParseGitUrl(gs.GitRepoUrl("repo"))
 		err := vl.LoadVars(vc, &types.VarsSource{
 			Git: &types.VarsSourceGit{
 				Url:  *url,
@@ -237,7 +236,7 @@ func TestVarsLoader_Git(t *testing.T) {
 	})
 
 	testVarsLoader(t, func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
-		url, _ := git_url.Parse(gs.GitRepoUrl("repo"))
+		url, _ := types.ParseGitUrl(gs.GitRepoUrl("repo"))
 		b := true
 		err := vl.LoadVars(vc, &types.VarsSource{
 			IgnoreMissing: &b,
@@ -274,7 +273,7 @@ func TestVarsLoader_GitBranch(t *testing.T) {
 	assert.NoError(t, err)
 
 	testVarsLoader(t, func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
-		url, _ := git_url.Parse(gs.GitRepoUrl("repo"))
+		url, _ := types.ParseGitUrl(gs.GitRepoUrl("repo"))
 		err = vl.LoadVars(vc, &types.VarsSource{
 			Git: &types.VarsSourceGit{
 				Url:  *url,
@@ -293,7 +292,8 @@ func TestVarsLoader_ClusterConfigMap(t *testing.T) {
 	cm := corev1.ConfigMap{
 		ObjectMeta: v1.ObjectMeta{Name: "cm", Namespace: "ns"},
 		Data: map[string]string{
-			"vars": `{"test1": {"test2": 42}}`,
+			"vars":  `{"test1": {"test2": 42}}`,
+			"value": "42",
 		},
 	}
 
@@ -343,6 +343,32 @@ func TestVarsLoader_ClusterConfigMap(t *testing.T) {
 		}, nil, "")
 		assert.NoError(t, err)
 	}, &cm)
+
+	testVarsLoader(t, func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+		err := vl.LoadVars(vc, &types.VarsSource{
+			ClusterConfigMap: &types.VarsSourceClusterConfigMapOrSecret{
+				Name:      "cm",
+				Namespace: "ns",
+				Key:       "value",
+			},
+		}, nil, "")
+		assert.Errorf(t, err, "failed to load vars from kubernetes object ns/ConfigMap/cm and key value: value is not a YAML dictionary")
+	}, &cm)
+
+	testVarsLoader(t, func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+		err := vl.LoadVars(vc, &types.VarsSource{
+			ClusterConfigMap: &types.VarsSourceClusterConfigMapOrSecret{
+				Name:       "cm",
+				Namespace:  "ns",
+				Key:        "value",
+				TargetPath: "deep.nested.path",
+			},
+		}, nil, "")
+		assert.NoError(t, err)
+
+		v, _, _ := vc.Vars.GetNestedInt("deep", "nested", "path")
+		assert.Equal(t, int64(42), v)
+	}, &cm)
 }
 
 func TestVarsLoader_ClusterSecret(t *testing.T) {
@@ -479,19 +505,19 @@ func TestVarsLoader_SystemEnv(t *testing.T) {
 		assert.NoError(t, err)
 
 		v, _, _ := vc.Vars.GetNestedField("test1")
-		assert.Equal(t, 42, v)
+		assert.Equal(t, 42., v)
 
 		v, _, _ = vc.Vars.GetNestedField("test2")
 		assert.Equal(t, "43", v)
 
 		v, _, _ = vc.Vars.GetNestedField("test3", "test4")
-		assert.Equal(t, 44, v)
+		assert.Equal(t, 44., v)
 
 		v, _, _ = vc.Vars.GetNestedField("test5")
 		assert.Equal(t, "def", v)
 
 		v, _, _ = vc.Vars.GetNestedField("test6")
-		assert.Equal(t, 42, v)
+		assert.Equal(t, 42., v)
 
 		v, _, _ = vc.Vars.GetNestedField("test7")
 		assert.Equal(t, "", v)
